import { useEffect, useState } from "react";
import { useDomain } from "@/hook/useDomain";
import { Button, Modal, Select, Space, Table, Tooltip } from "antd";
import { columns } from "./columns";
import { DesktopOutlined, TagOutlined } from "@ant-design/icons";
import { openOHIFViewer } from "@/modules/Admin/Dicom/Upload/util";

interface ArchiveListProps {
  children?: JSX.Element;
}

type CategoryItemType = {
  labels: { name: string; id: number }[];
};

export const ArchiveList = (props: ArchiveListProps) => {
  const [dataSource, setDataSource] = useState<CategoryItemType[]>([]);
  const [tableLoading, setTableLoading] = useState(false);
  const { userDomainService, labelDomainService } = useDomain();
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [labelOptions, setLabelOptions] = useState<
    { label: string; value: string }[]
  >([]);

  useEffect(() => {
    userDomainService.findArchiveTask().then((res) => {
      const { code, data } = res;
      if (code === 0) {
        setDataSource(data);
      }
      setTableLoading(false);
    });
  }, [userDomainService]);

  useEffect(() => {
    labelDomainService.findLabelCategory().then((res) => {
      const { code, data } = res;
      if (code === 0) {
        const labels = (data as CategoryItemType[])
          .map((i) => i.labels)
          .flat()
          .map((i) => ({ label: i.name, value: String(i.id) }));
        setLabelOptions(labels);
      }
    });
  }, []);

  const onViewDicom = (record: any) => {
    const { StudyInstanceUID, SeriesInstanceUID } = record;
    openOHIFViewer(StudyInstanceUID, SeriesInstanceUID);
  };

  const onLabelSelectChange = (labelIds: string[]) => {
    console.log(
      "选中的labelIds:",
      labelIds.map((i) => Number(i))
    );
  };

  const onUpdateLabelForSeries = () => {
    console.log("onUpdateLabelForSeries");
  };

  const filterOption = (
    input: string,
    option: { label: string; value: string }
  ) => (option?.label ?? "").toLowerCase().includes(input.toLowerCase());

  return (
    <div>
      <Table
        dataSource={dataSource}
        loading={tableLoading}
        columns={[
          ...columns,
          {
            title: "操作",
            dataIndex: "operation",
            render: (_: any, record: any) => (
              <Space>
                <Tooltip title="在线阅片">
                  <Button
                    type="text"
                    icon={<DesktopOutlined />}
                    onClick={() => onViewDicom(record)}
                  />
                </Tooltip>
                <Tooltip title="添加标签">
                  <Button
                    type="text"
                    icon={<TagOutlined />}
                    onClick={() => setIsModalOpen(true)}
                  />
                </Tooltip>
              </Space>
            ),
          },
        ]}
        rowKey="id"
      />
      <Modal
        open={isModalOpen}
        title="添加标签"
        cancelText="再想想"
        okText="确认"
        onCancel={() => setIsModalOpen(false)}
        onOk={onUpdateLabelForSeries}
      >
        <Select
          mode="multiple"
          allowClear
          style={{ width: "100%" }}
          placeholder="请选择标签"
          defaultValue={[]}
          onChange={onLabelSelectChange}
          options={labelOptions}
          optionFilterProp="children"
          filterOption={filterOption}
        />
      </Modal>
    </div>
  );
};
