import { Controller } from '@nestjs/common';
import { MessagePattern } from '@nestjs/microservices';
import { LabelService } from './label.service';

@Controller()
export class LabelController {
  constructor(private readonly labelService: LabelService) {}

  @MessagePattern('dicom.label.category.create')
  async createLabelCategory(payload) {
    const inserted = await this.labelService.createLabelCategory(payload);
    return { statusCode: 200, data: inserted };
  }

  @MessagePattern('dicom.label.create')
  async createLabel(payload) {
    const data = await this.labelService.createLabel(payload);
    return { statusCode: 200, data };
  }

  @MessagePattern('dicom.label.update')
  async updateLabel(payload) {
    const data = await this.labelService.updateLabel(payload);
    return { statusCode: 200, data };
  }

  @MessagePattern('dicom.label.category.find.all')
  async findAllLabelCategory() {
    return await this.labelService.findAllLabelCategory();
  }

  @MessagePattern('dicom.label.delete')
  async deleteLabel(payload) {
    const { affected } = await this.labelService.deleteLabel(payload);
    return { statusCode: affected > 0 ? 200 : -1 };
  }

  @MessagePattern('dicom.label.category.update')
  async updateLabelCategory(payload) {
    const { affected } = await this.labelService.updateLabelCategory(payload);
    return { statusCode: affected > 0 ? 200 : -1 };
  }
}
